@@ -8,7 +8,7 @@ from ._sqlalchemy import SQLAlchemy
 
 class PostgresClient(SQLAlchemy):
 
-    def __init__(self, host: str, port: str, username: str, password: str, database: str, schema: str = "public") -> None:
+    def __init__(self, host: str, port: str, username: str, password: str, database: str, schema: str = None) -> None:
         """
             Creates and initializes a PostgreSQL engine instance that connects to the database
 
@@ -18,10 +18,9 @@ class PostgresClient(SQLAlchemy):
                 username (str): Username for authentication/privileges
                 password (str): Password for authentication
                 database (str): Name of the database
-                schema (str): Schema for the database
         """
         super().__init__(engine = "postgresql", host = host, port = port, database = database, username = username, password = password)
-        self.engine = create_engine(self.connection_string, connect_args = {"options": f"-csearch_path={schema}"})
+        self.engine = create_engine(self.connection_string)
 
 
     @property
